@@ -1,9 +1,10 @@
 package SSIS::Package::ConnectionManager::FLATFILE;
 
 use 5.010;
-use Mouse;
+use strict;
+use warnings;
 
-extends 'SSIS::Package::ConnectionManager';
+use parent qw/SSIS::Package::ConnectionManager/;
 
 =head1 NAME
 
@@ -11,11 +12,11 @@ SSIS::Package::ConnectionManager::FLATFILE - SSIS FLATFILE package connection ma
 
 =head1 VERSION
 
-Version 0.02
+Version 0.01
 
 =cut
 
-#our $VERSION = '0.02';
+our $VERSION = '0.01';
 
 
 1 ;
